<h1 align="center">NoneBot Plugin Kuma-san</h1></br>


<p align="center">用于查询斯普拉遁3场地信息的 NoneBot2 插件</p></br>
<p align="center">
    <img src="https://img.shields.io/github/license/monsterxcn/nonebot_plugin_epicfree?style=flat-square" alt="license">
    <img src="https://img.shields.io/pypi/v/nonebot_plugin_epicfree?style=flat-square" alt="pypi">
  <img src="https://img.shields.io/badge/python-3.8+-blue?style=flat-square" alt="python"><br />
</p></br>

## 安装


使用以下命令之一安装：


```
nb plugin install nonebot_plugin_kuma_san
```
```
pip install nonebot_plugin_kuma_san
```

## 更新
v.1.1.0 2023.8.3 更新武器和场地的中日文翻译，添加新版本的武器和场地信息

## 使用

对已安装本插件的nonebot发送以下指令可获取对应的场地信息

reg (涂地)/chal (真格挑战)/open (真格开放)/baito (打工)/fest (祭典)/x (x段) + (可选)now/next

比如"open now"指令查询现在的真格开放场地信息


## 感谢

[@nonebot/nonebot2](https://github.com/nonebot/nonebot2/) | [@Mrs4s/go-cqhttp](https://github.com/Mrs4s/go-cqhttp) | api来自[Spla3 API](https://spla3.yuu26.com/)

> 作者从代码到nonebot都是新手，写得不好请多包涵
